TempoProviderExt

Trait TempoProviderExt 

pub trait TempoProviderExt: Provider<TempoNetwork> {
    // Provided methods
    fn account_keychain(&self) -> IAccountKeychainInstance<&Self, TempoNetwork>
       where Self: Sized { ... }
    fn get_keychain_key<'life0, 'async_trait>(
        &'life0 self,
        account: Address,
        key_id: Address,
    ) -> Pin<Box<dyn Future<Output = ContractResult<KeyInfo>> + Send + 'async_trait>>
       where Self: Sized + Sync + 'async_trait,
             'life0: 'async_trait { ... }
    fn get_keychain_remaining_limit<'life0, 'async_trait>(
        &'life0 self,
        account: Address,
        key_id: Address,
        token: Address,
    ) -> Pin<Box<dyn Future<Output = ContractResult<U256>> + Send + 'async_trait>>
       where Self: Sized + Sync + 'async_trait,
             'life0: 'async_trait { ... }
    fn get_keychain_transaction_key<'life0, 'async_trait>(
        &'life0 self,
    ) -> Pin<Box<dyn Future<Output = ContractResult<Address>> + Send + 'async_trait>>
       where Self: Sized + Sync + 'async_trait,
             'life0: 'async_trait { ... }
}
Extension trait for [Provider] with Tempo-specific functionality.

Provided Methods

fn account_keychain(&self) -> IAccountKeychainInstance<&Self, TempoNetwork>
where Self: Sized,

Returns a typed instance for the Account Keychain precompile.

fn get_keychain_key<'life0, 'async_trait>( &'life0 self, account: Address, key_id: Address, ) -> Pin<Box<dyn Future<Output = ContractResult<KeyInfo>> + Send + 'async_trait>>
where Self: Sized + Sync + 'async_trait, 'life0: 'async_trait,

Returns information about a key authorized for an account.

fn get_keychain_remaining_limit<'life0, 'async_trait>( &'life0 self, account: Address, key_id: Address, token: Address, ) -> Pin<Box<dyn Future<Output = ContractResult<U256>> + Send + 'async_trait>>
where Self: Sized + Sync + 'async_trait, 'life0: 'async_trait,

Returns the remaining spending limit for an account/key/token tuple.

fn get_keychain_transaction_key<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = ContractResult<Address>> + Send + 'async_trait>>
where Self: Sized + Sync + 'async_trait, 'life0: 'async_trait,

Returns the key ID used in the current transaction context.

Implementors

Source

impl<P> TempoProviderExt for P
where P: Provider<TempoNetwork>,